@@ -26,13 +26,14 @@ class Select(AbstractStatement):
     offset: int | None = None
     limit: int | None = None
     output_format: OutputFormat = OutputFormat.Dict
-    distinct_on: list[Selectable] = field(default_factory=list)
+    distinct_on: list[Selectable] | Selectable | None = field(default_factory=list)
 
 
     def __post_init__(self):
         self.table.get_table_engine().preprocess_select_request(self)
 
         self.selectables = to_list(self.selectables) if self.selectables is not None else []
+        self.distinct_on = to_list(self.distinct_on) if self.distinct_on is not None else []
         self.group_by = to_list(self.group_by) if self.group_by is not None else []
         self.order_by = to_list(self.order_by) if self.order_by is not None else []
 
